@@ -2,6 +2,7 @@ from requests import Session
 from typing import Optional, Union, List, Tuple
 from arrapi import LanguageProfile, RootFolder, QualityProfile, Series, Tag, NotFound, Invalid, Exists
 from .base import BaseAPI
+from ..exceptions import Excluded
 from ..objs.simple import SonarrExclusion
 from ..raws.sonarr import SonarrRawAPI
 
@@ -21,21 +22,24 @@ class SonarrAPI(BaseAPI):
         self.monitor_options = ["all", "future", "missing", "existing", "pilot", "firstSeason", "latestSeason", "none"]
         self.series_type_options = ["standard", "daily", "anime"]
 
-    def _validate_add_options(self, root_folder, quality_profile, language_profile, monitor="all",
+    def _validate_add_options(self, root_folder, quality_profile, language_profile=None, monitor="all",
                               season_folder=True, search=True, unmet_search=False, series_type="standard",
                               tags=None):
         """ Validate Add Series options. """
         options = {
             "root_folder": self._validate_root_folder(root_folder),
-            "quality_profile" if self._raw.v3 else "profileId": self._validate_quality_profile(quality_profile),
-            "language_profile": self._validate_language_profile(language_profile),
+            "quality_profile" if self._raw.new_codebase else "profileId": self._validate_quality_profile(quality_profile),
             "monitor": self._validate_monitor(monitor),
             "monitored": monitor != "none",
-            "season_folder": True if season_folder else False,
-            "search": True if search else False,
-            "unmet_search": True if unmet_search else False,
+            "season_folder": True if season_folder is True else False,
+            "search": True if search is True else False,
+            "unmet_search": True if unmet_search is True else False,
             "series_type": self._validate_series_type(series_type),
         }
+        if not self._raw.v4:
+            if not language_profile:
+                raise Invalid("Language Profile Required")
+            options["language_profile"] = self._validate_language_profile(language_profile),
         if tags:
             options["tags"] = self._validate_tags(tags)
         return options
@@ -49,21 +53,21 @@ class SonarrAPI(BaseAPI):
         if all(v is None for v in variables):
             raise ValueError("Expected either root_folder, path, quality_profile, language_profile, "
                              "monitor, monitored, season_folder, series_type, or tags args")
-        options = {"moveFiles": True if move_files else False}
+        options = {"moveFiles": True if move_files is True else False}
         if root_folder is not None:
             options["rootFolderPath"] = self._validate_root_folder(root_folder)
         if path is not None:
             options["path"] = path
         if quality_profile is not None:
-            options["qualityProfileId" if self._raw.v3 else "profileId"] = self._validate_quality_profile(quality_profile)
-        if language_profile is not None:
+            options["qualityProfileId" if self._raw.new_codebase else "profileId"] = self._validate_quality_profile(quality_profile)
+        if language_profile is not None and not self._raw.v4:
             options["languageProfileId"] = self._validate_language_profile(language_profile)
         if monitor is not None:
             options["monitor"] = self._validate_monitor(monitor)
         if monitored is not None:
-            options["monitored"] = True if monitored else False
+            options["monitored"] = True if monitored is True else False
         if season_folder is not None:
-            options["seasonFolder"] = True if season_folder else False
+            options["seasonFolder"] = True if season_folder is True else False
         if series_type is not None:
             options["seriesType"] = self._validate_series_type(series_type)
         if tags is not None:
@@ -180,6 +184,7 @@ class SonarrAPI(BaseAPI):
                 :class:`~arrapi.exceptions.NotFound`: When there's no series with that ID.
                 :class:`~arrapi.exceptions.Invalid`: When one of the options given is invalid.
                 :class:`~arrapi.exceptions.Exists`: When the Series already Exists in Sonarr.
+                :class:`~arrapi.exceptions.Excluded`: When the Series Exists in the Exclusion List.
         """
         series = self.get_series(series_id=series_id, tvdb_id=tvdb_id)
         series.add(root_folder, quality_profile, language_profile, monitor=monitor, season_folder=season_folder,
@@ -221,7 +226,7 @@ class SonarrAPI(BaseAPI):
                 :class:`~arrapi.objs.reload.Series`: Series for the ID given.
 
             Raises:
-                :class:`ValueError`: When no ID is given or when theres no options given.
+                :class:`ValueError`: When no ID is given or when there's no options given.
                 :class:`~arrapi.exceptions.Invalid`: When one of the options given is invalid.
                 :class:`~arrapi.exceptions.NotFound`: When there's no series with that ID or when the Series hasn't been added to Sonarr.
         """
@@ -260,7 +265,7 @@ class SonarrAPI(BaseAPI):
     def add_multiple_series(self, ids: List[Union[Series, int, Tuple[Union[Series, int], str]]],
                             root_folder: Union[str, int, RootFolder],
                             quality_profile: Union[str, int, QualityProfile],
-                            language_profile: Union[str, int, LanguageProfile],
+                            language_profile: Optional[Union[str, int, LanguageProfile]] = None,
                             monitor: str = "all",
                             season_folder: bool = True,
                             search: bool = True,
@@ -268,7 +273,7 @@ class SonarrAPI(BaseAPI):
                             series_type: str = "standard",
                             tags: Optional[List[Union[str, int, Tag]]] = None,
                             per_request: int = None
-                            ) -> Tuple[List[Series], List[Series], List[Union[int, Series]]]:
+                            ) -> Tuple[List[Series], List[Series], List[Union[int, Series]], List[int]]:
         """ Adds multiple Series to Sonarr in a single call by their TVDb IDs.
 
             You can specify the path for each TVDb ID using a tuple in the list instead of just the ID ex. ``(121361, "/media/Game of Thrones/")``
@@ -279,7 +284,7 @@ class SonarrAPI(BaseAPI):
                 ids (List[Union[Series, int, Tuple[Union[Series, int], str]]]): List of TVDB IDs or Series lookups to add.
                 root_folder (Union[str, int, RootFolder]): Root Folder for the Series.
                 quality_profile (Union[str, int, QualityProfile]): Quality Profile for the Series.
-                language_profile (Union[str, int, LanguageProfile]): Language Profile for the Series.
+                language_profile (Optional[Union[str, int, LanguageProfile]]): Language Profile for the Series. Required for older versions only.
                 monitor (bool): How to monitor the Series. Valid options are ``all``, ``future``, ``missing``, ``existing``, ``pilot``, ``firstSeason``, ``latestSeason``, or ``none``.
                 season_folder (bool): Use Season Folders for the Series.
                 search (bool): Start search for missing episodes of the Series after adding.
@@ -289,18 +294,19 @@ class SonarrAPI(BaseAPI):
                 per_request (int): Number of Series to add per request.
 
             Returns:
-                Tuple[List[:class:`~arrapi.objs.reload.Series`], List[:class:`~arrapi.objs.reload.Series`], List[Union[int, Series]]]: List of Series that were able to be added, List of Series already in Sonarr, List of Series that could not be found or were excluded.
+                Tuple[List[:class:`~arrapi.objs.reload.Series`], List[:class:`~arrapi.objs.reload.Series`], List[Union[int, Series]], List[int]]: List of Series that were able to be added, List of Series already in Sonarr, List of Series that could not be found, List of Movies that were excluded.
 
             Raises:
                 :class:`~arrapi.exceptions.Invalid`: When one of the options given is invalid.
         """
-        options = self._validate_add_options(root_folder, quality_profile, language_profile, monitor=monitor,
-                                             season_folder=season_folder, search=search, unmet_search=unmet_search,
-                                             series_type=series_type, tags=tags)
+        options = self._validate_add_options(root_folder, quality_profile, language_profile=language_profile,
+                                             monitor=monitor, season_folder=season_folder, search=search,
+                                             unmet_search=unmet_search, series_type=series_type, tags=tags)
         json = []
         series = []
         existing_series = []
         invalid_ids = []
+        excluded_ids = []
         used_ids = []
         for input_item in ids:
             path = input_item[1] if isinstance(input_item, tuple) else None
@@ -310,10 +316,10 @@ class SonarrAPI(BaseAPI):
                     show = item
                 else:
                     if int(item) in used_ids or (self.exclusions and int(item) in self.exclusions):
-                        raise NotFound
+                        raise Excluded(int(item))
                     show = self.get_series(tvdb_id=item)
                 if show.tvdbId in used_ids or (self.exclusions and show.tvdbId in self.exclusions):
-                    raise NotFound
+                    raise Excluded(show.tvdbId)
                 used_ids.append(show.tvdbId)
                 try:
                     json.append(show._get_add_data(options, path=path))
@@ -321,12 +327,14 @@ class SonarrAPI(BaseAPI):
                     existing_series.append(show)
             except NotFound:
                 invalid_ids.append(input_item)
+            except Excluded as e:
+                excluded_ids.append(int(str(e)))
         if len(json) > 0:
             if per_request is None:
                 per_request = len(json)
             for i in range(0, len(json), per_request):
                 series.extend([Series(self, data=s) for s in self._raw.post_series_import(json[i:i+per_request])])
-        return series, existing_series, invalid_ids
+        return series, existing_series, invalid_ids, excluded_ids
 
     def edit_multiple_series(self, ids: List[Union[Series, int]],
                              root_folder: Optional[Union[str, int, RootFolder]] = None,
